@@ -1,6 +1,7 @@
 """
 This module provides classes and functions for working with REST channel.
 """
+from enum import StrEnum
 
 """
 " ██╗  ██╗██╗   ██╗███╗   ███╗ █████╗ ████████╗██████╗  ██████╗ ███╗   ██╗
@@ -26,6 +27,25 @@ from typing import NamedTuple, Optional, Callable
 import requests
 
 
+class RestRequestType(StrEnum):
+    """
+    Represents a set of requests types for REST communication channel.
+    """
+
+    MESSAGE = 'message'
+    """
+    This request is sent to the REST channel server endpoint when one or more new messages are available for 
+    the worker instance.
+    """
+
+    HEARTBEAT = 'heartbeat'
+    """
+    In addition to 'message' requests, the client application can send regular 'heartbeat' requests to the REST channel 
+    server.These 'heartbeat' requests do not contain any significant data; their primary purpose is to prompt the server 
+    to respond to previous 'message' requests from the worker instance that have accumulated on the REST channel server.
+    """
+
+
 class RequestMessagePayloadPart(NamedTuple):
     """
     Represents a part of a REST request payload, containing metadata and content.
@@ -65,8 +85,8 @@ class RestChannelRequest(NamedTuple):
 
     req_id: str
     """Unique identifier for the request."""
-    req_cmd: str
-    """Type of the request, either 'message' or 'heartbeat'."""
+    req_cmd: RestRequestType
+    """Type of the request."""
     payload: list[RequestMessagePayloadPart]
     """List of payload parts attached to the request."""
     req_tstamp: str
@@ -88,7 +108,7 @@ class RestChannelRequest(NamedTuple):
         if not payload:
             raise ValueError('Payload cannot be empty.')
 
-        return cls(str(uuid.uuid4()), 'message', payload, _utc_now_iso_format())
+        return cls(str(uuid.uuid4()), RestRequestType.MESSAGE, payload, _utc_now_iso_format())
 
     @classmethod
     def make_heartbeat(cls) -> 'RestChannelRequest':
@@ -98,7 +118,7 @@ class RestChannelRequest(NamedTuple):
         @return:
             A new 'heartbeat' request with no payload.
         """
-        return cls(str(uuid.uuid4()), 'heartbeat', [], _utc_now_iso_format())
+        return cls(str(uuid.uuid4()), RestRequestType.HEARTBEAT, [], _utc_now_iso_format())
 
 
 class ResponseMessagePayloadPart(NamedTuple):
@@ -158,7 +178,7 @@ def _post(url: str, headers: dict[str, str], req: RestChannelRequest) -> Optiona
     """
     msg = {'req_cmd': req.req_cmd, 'req_id': req.req_id, 'req_tstamp': req.req_tstamp}
 
-    if req.req_cmd == 'message':
+    if req.req_cmd == RestRequestType.MESSAGE:
         msg['payload'] = [r._asdict() for r in req.payload]
 
     res = requests.post(url, json.dumps(msg), headers=headers)
